@@ -274,24 +274,6 @@ public:
 		reset(v);
 	}
 
-	size_t find(typeref<T> v, size_t start = 0) {
-		for(size_t index = start; index < size(); ++index) {
-			if(is(index) && at(index) == v) {
-				return index;
-			}
-		}
-		return (size_t)(-1);
-	}
-
-	size_t count(typeref<T> v) {
-		size_t found = 0;
-		for(size_t index = 0; index < size(); ++index) {
-			if(is(index) && at(index) == v)
-				++found;
-		}
-		return found;
-	}
-
 	inline arrayref& operator=(const arrayref& copy) {
 		TypeRef::set(copy);
 		return *this;
@@ -345,8 +327,8 @@ public:
 	}
 };
 
-typedef arrayref<bytes> bytearray_t;
-typedef arrayref<chars> stringarray_t;
+typedef arrayref<Type::Bytes> bytearray_t;
+typedef arrayref<Type::Chars> stringarray_t;
 
 } // namespace
 
