@@ -194,7 +194,7 @@ public:
 	/**
 	 * Manually release the current container.
 	 */
-	void release(void);
+	void clear(void);
 
 	/**
 	 * Get size of referenced heap object.
@@ -322,7 +322,7 @@ public:
 	}
 
 	inline void set(T& object) {
-		release();
+		clear();
 		caddr_t p = TypeRef::alloc(sizeof(value));
 		TypeRef::set(new(mem(p)) value(p, object));
 	}
@@ -510,27 +510,27 @@ public:
 	static void destroy(value *bytes);
 };
 
-typedef	const char *chars;
-typedef	const uint8_t *bytes;
-typedef const uint8_t *bools;
-typedef typeref<chars>::value *charvalues_t;
-typedef	typeref<bytes>::value *bytevalues_t;
-typedef	typeref<chars> stringref_t;
-typedef typeref<chars> stringref;
-typedef typeref<bytes> byteref_t;
-typedef typeref<bytes> byteref;
-typedef typeref<bools> boolref_t;
+namespace Type {
+	typedef int32_t Integer;
+	typedef double Real;
+	typedef const char *Chars;
+	typedef const uint8_t *Bytes;
+	typedef const uint8_t *Bools;
+}
+
+typedef typeref<Type::Chars>::value *charvalues_t;
+typedef	typeref<Type::Bytes>::value *bytevalues_t;
+typedef	typeref<Type::Chars> stringref_t;
+typedef typeref<Type::Chars> stringref;
+typedef typeref<Type::Bytes> byteref_t;
+typedef typeref<Type::Bytes> byteref;
+typedef typeref<Type::Bools> boolref_t;
 
 template<typename T>
 inline typeref<T> typeref_cast(T x) {
 	return typeref<T>(x);
 }
 
-template<>
-inline bool is<TypeRef>(TypeRef& obj) {
-	return obj.is();
-}
-
 } // namespace
 
 #endif
