@@ -1,4 +1,5 @@
 // Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -141,8 +142,9 @@ protected:
      * End of document check.
      * @return true if end of document.
      */
-    bool end(void) const
-        {return state == END;}
+    bool end(void) const {
+        return state == END;
+    }
 };
 
 } // namespace ucommon
